@@ -5,6 +5,14 @@ pub struct Factory<T: 'static> {
     inner: *mut InnerPool<T>,
 }
 
+impl<T> Default for Factory<T> {
+    fn default() -> Self {
+        Self {
+            inner: std::ptr::null_mut(),
+        }
+    }
+}
+
 impl<T> Factory<T> {
     pub(crate) fn new(inner: *mut InnerPool<T>) -> Self {
         Self { inner }
